@@ -1,18 +1,19 @@
 from .version import __version__
 from .factory import create_model
-
 from .registry import *
 from .network import NetworkImageNet
 from .registry import register_model
+from .utils import _remove_module, _set_config
 
 from collections import namedtuple
 import torch.utils.model_zoo as model_zoo
-from collections import OrderedDict
 import json
 import pkg_resources
 
+from .resnet import *
+from .tresnet import *
 from .nasnet import NASNetAMobile
-from .nsga import NSGANetV2
+from .nsga import *
 
 Genotype = namedtuple('Genotype', 'normal normal_concat reduce reduce_concat')
 
@@ -25,26 +26,6 @@ url_cfgs = {
     'eeea_c2' : 'https://github.com/jitdee-ai/darmo/releases/download/0.0.1/eeea-c2.pt',
 }
 
-def _remove_module(state_dict):
-    new_state_dict = OrderedDict()
-    for k, v in state_dict.items():
-        name = k[7:]
-        new_state_dict[name] = v
-    return new_state_dict
-
-def _set_config(_config={}, name=None, first_channels=48, layers=14, auxiliary=True, 
-                        genotype=None, last_bn=False, pretrained=False, num_classes=1000):
-
-    _config['name'] = name
-    _config['first_channels'] = first_channels
-    _config['layers'] = layers
-    _config['auxiliary'] = auxiliary
-    _config['genotype'] = genotype
-    _config['last_bn'] = last_bn
-    _config['pretrained'] = pretrained
-    _config['num_classes'] = num_classes
-    return _config
-
 def _load_pre_trained(config):
     if config['name'] == 'nasnet':
         base_net = NASNetAMobile()
@@ -74,7 +55,7 @@ def _load_pre_trained(config):
     return base_net
 
 @register_model
-def dartsv2(pretrained=True, num_classes=1000, auxiliary=True):
+def dartsv2(pretrained=True, num_classes=1000, auxiliary=False):
     dartsv2 = Genotype(normal=[('sep_conv_3x3', 0), ('sep_conv_3x3', 1), ('sep_conv_3x3', 0), ('sep_conv_3x3', 1), ('sep_conv_3x3', 1), ('skip_connect', 0), ('skip_connect', 0), ('dil_conv_3x3', 2)], normal_concat=[2, 3, 4, 5], reduce=[('max_pool_3x3', 0), ('max_pool_3x3', 1), ('skip_connect', 2), ('max_pool_3x3', 1), ('max_pool_3x3', 0), ('skip_connect', 2), ('skip_connect', 2), ('max_pool_3x3', 1)], reduce_concat=[2, 3, 4, 5])
     config = _set_config(_config={}, name= 'dartsv2', first_channels=48, layers=14, auxiliary=auxiliary, 
                         genotype=dartsv2, last_bn=False, pretrained=pretrained, num_classes=num_classes)
@@ -82,7 +63,7 @@ def dartsv2(pretrained=True, num_classes=1000, auxiliary=True):
     return _load_pre_trained(config)
 
 @register_model
-def pdarts(pretrained=True, num_classes=1000, auxiliary=True):
+def pdarts(pretrained=True, num_classes=1000, auxiliary=False):
 
     pdarts = Genotype(normal=[('skip_connect', 0), ('dil_conv_3x3', 1), ('skip_connect', 0),('sep_conv_3x3', 1), ('sep_conv_3x3', 1), ('sep_conv_3x3', 3), ('sep_conv_3x3',0), ('dil_conv_5x5', 4)], normal_concat=range(2, 6), reduce=[('avg_pool_3x3', 0), ('sep_conv_5x5', 1), ('sep_conv_3x3', 0), ('dil_conv_5x5', 2), ('max_pool_3x3', 0), ('dil_conv_3x3', 1), ('dil_conv_3x3', 1), ('dil_conv_5x5', 3)], reduce_concat=range(2, 6))
 
@@ -92,7 +73,7 @@ def pdarts(pretrained=True, num_classes=1000, auxiliary=True):
     return _load_pre_trained(config)
 
 @register_model
-def relative_nas(pretrained=True, num_classes=1000, auxiliary=True):
+def relative_nas(pretrained=True, num_classes=1000, auxiliary=False):
 
     relative_nas = Genotype( normal=[ ('sep_conv_3x3', 0), ('dil_conv_5x5', 1), ('sep_conv_3x3', 1), ('sep_conv_3x3', 1), ('sep_conv_3x3', 1), ('sep_conv_5x5', 1), ('skip_connect', 0), ('sep_conv_3x3', 0) ], normal_concat=range(2, 6), reduce=[ ('avg_pool_3x3', 1), ('max_pool_3x3', 1), ('dil_conv_5x5', 1), ('max_pool_3x3', 1), ('avg_pool_3x3', 3), ('skip_connect', 1), ('dil_conv_5x5', 3), ('sep_conv_3x3', 1) ], reduce_concat=range(2, 6) )
     
@@ -109,18 +90,3 @@ def nasnet(pretrained=True, num_classes=1000, auxiliary=True):
 
     return _load_pre_trained(config)
 
-@register_model
-def eeea_c1(pretrained=True, num_classes=1000, auxiliary=True):
-
-    config = _set_config(_config={}, name= 'eeea_c1', first_channels=46, layers=14, auxiliary=auxiliary, 
-                        genotype=None, last_bn=False, pretrained=pretrained, num_classes=num_classes)
-
-    return _load_pre_trained(config)
-
-@register_model
-def eeea_c2(pretrained=True, num_classes=1000, auxiliary=True):
-
-    config = _set_config(_config={}, name= 'eeea_c2', first_channels=46, layers=14, auxiliary=auxiliary, 
-                        genotype=None, last_bn=False, pretrained=pretrained, num_classes=num_classes)
-
-    return _load_pre_trained(config)
